@@ -11,7 +11,7 @@ use Carp();
 use English qw( -no_match_vars );
 use DirHandle();
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -89,6 +89,7 @@ sub new {
           || $ENV{TZDIR}
           || _DEFAULT_ZONEINFO_DIRECTORY() );
     $self->timezone( $params->{timezone} || $ENV{TZ} );
+    $self->offset( $params->{offset} );
     return $self;
 }
 
@@ -101,6 +102,15 @@ sub directory {
     return $old;
 }
 
+sub offset {
+    my ( $self, $new ) = @_;
+    my $old = $self->{offset};
+    if ( @_ > 1 ) {
+        $self->{offset} = $new;
+    }
+    return $old;
+}
+
 sub _timezones {
     my ($self) = @_;
     my $path = File::Spec->catfile( $self->directory(), 'zone.tab' );
@@ -367,6 +377,9 @@ sub _get_time_for_wday_week_month_year {
 
 sub _get_tz_offset_according_to_v2_tz_rule {
     my ( $self, $time ) = @_;
+    if ( defined $self->offset() ) {
+        return ( 0, $self->offset() * _SECONDS_IN_ONE_MINUTE(), q[] );
+    }
     my $tz = $self->timezone();
     my ( $isdst, $gmtoff, $abbr );
     my $tz_definition = $self->{_tzdata}->{$tz}->{tz_definition};
@@ -765,6 +778,9 @@ sub _negative_time_local {
 
 sub _get_isdst_gmtoff_abbr_converted_from_gmt_base {
     my ( $self, $time ) = @_;
+    if ( defined $self->offset() ) {
+        return ( 0, $self->offset() * _SECONDS_IN_ONE_MINUTE(), q[] );
+    }
     my ( $isdst, $gmtoff, $abbr );
     my $tz = $self->timezone();
     $self->_read_tzfile();
@@ -849,6 +865,9 @@ sub _get_isdst_gmtoff_abbr_converted_from_gmt_base {
 sub _get_isdst_gmtoff_abbr_as_localtime {
     my ( $self, $time ) = @_;
     my ( $isdst, $gmtoff, $abbr );
+    if ( defined $self->offset() ) {
+        return ( 0, $self->offset() * _SECONDS_IN_ONE_MINUTE(), q[] );
+    }
     my $tz = $self->timezone();
     $self->_read_tzfile();
     my $transition_index = 0;
@@ -920,6 +939,16 @@ sub _get_isdst_gmtoff_abbr_as_localtime {
     return ( $isdst, $gmtoff, $abbr );
 }
 
+sub local_offset {
+    my ( $self, $time ) = @_;
+    if ( !defined $time ) {
+        $time = time;
+    }
+    my ( $isdst, $gmtoff, $abbr ) =
+      $self->_get_isdst_gmtoff_abbr_as_localtime($time);
+    return int( $gmtoff / _SECONDS_IN_ONE_MINUTE() );
+}
+
 sub local_time {
     my ( $self, $time ) = @_;
     if ( !defined $time ) {
@@ -1462,7 +1491,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -1514,6 +1543,10 @@ This object method can be used to get or set the root directory of the Olson dat
 
 This object method can be used to get or set the timezone, which will affect all future calls to L</local_time> or L</time_local>.  The parameter for this method should be in the Olson format of a timezone, such as C<"Australia/Melbourne">.
 
+=head2 offset
+
+This object method can be used to get or set the offset for all L</local_time> or L</time_local> calls.  The offset should be specified in minutes from GMT.
+
 =head2 area
 
 This object method will return the area component of the current timezone, such as Australia
@@ -1522,13 +1555,17 @@ This object method will return the area component of the current timezone, such
 
 This object method will return the location component of the current timezone, such as Melbourne
 
+=head2 local_offset
+
+This object method takes the same arguments as C<localtime> but returns the appropriate offset from GMT in minutes.  This can to used as a C<offset> parameter to a subsequent call to Time::Zone::Olson.
+
 =head2 local_time
 
-This object method has the same signature as the 64 bit version of the C<localtime> function.  That is, it accepts up to a 64 bit signed integer as the sole argument and returns the C<(seconds, minutes, hours, day, month, year, wday, yday, isdst)> definition for the timezone for the object.  The timezone used to calculate the local_time may be specified as a parameter to the L</new> method or via the L</timezone> method.
+This object method has the same signature as the 64 bit version of the C<localtime> function.  That is, it accepts up to a 64 bit signed integer as the sole argument and returns the C<(seconds, minutes, hours, day, month, year, wday, yday, isdst)> definition for the timezone for the object.  The timezone used to calculate the local time may be specified as a parameter to the L</new> method or via the L</timezone> method.
 
 =head2 time_local
 
-This object method has the same signature as the 64 bit version of the C<Time::Local::timelocal> function.  That is, it accepts C<(seconds, minutes, hours, day, month, year, wday, yday, isdst)> as parameters in a list and returns the correct UNIX time in seconds according to the current timezone for the object.  The timezone used to calculate the local_time may be specified as a parameter to the L</new> method or via the L</timezone> method.  It may not return the same values as Time::Local::timelocal though, especially during timezone changes.
+This object method has the same signature as the 64 bit version of the C<Time::Local::timelocal> function.  That is, it accepts C<(seconds, minutes, hours, day, month, year, wday, yday, isdst)> as parameters in a list and returns the correct UNIX time in seconds according to the current timezone for the object.  The timezone used to calculate the local time may be specified as a parameter to the L</new> method or via the L</timezone> method.  It may not return the same values as Time::Local::timelocal though, especially during timezone changes.
 
 =head2 transition_times
 
